@@ -8,6 +8,7 @@ import pytest
 @pytest.fixture()
 def fews_config() -> FewsConfigReader:
     # we use config saved in this repo (=static), instead of downloading from repo 'wis_config'
+    assert constants.WIS_CONFIG_TEST_DIR.is_dir()
     fews_config = FewsConfigReader(path=constants.WIS_CONFIG_TEST_DIR)
     return fews_config
 
@@ -17,3 +18,10 @@ def loc_sets() -> LocationSetCollection:
     fews_config = FewsConfigReader(path=constants.WIS_CONFIG_TEST_DIR)
     loc_sets = LocationSetCollection(fews_config=fews_config)
     return loc_sets
+
+
+WIS_CONFIG_TEST_DIR = constants.BASE_DIR / "tests" / "data" / "input" / "config_wis60prd_202002"
+
+
+def test_test_dir_exists():
+    assert WIS_CONFIG_TEST_DIR.is_dir()
